@@ -72,6 +72,9 @@ typedef struct
   
 } t_wavelan;
 
+static void wavelan_set_size(XfcePanelPlugin* plugin, int size, t_wavelan *wavelan);
+static void wavelan_set_orientation(XfcePanelPlugin* plugin, GtkOrientation orientation, t_wavelan *wavelan);
+
 static void
 wavelan_set_state(t_wavelan *wavelan, gint state)
 {  
@@ -296,7 +299,6 @@ static t_wavelan *
 wavelan_new(XfcePanelPlugin *plugin)
 {
   t_wavelan *wavelan;
-  XfceScreenPosition screen_position;
   
   TRACE ("Entered wavelan_new");
   
@@ -310,12 +312,10 @@ wavelan_new(XfcePanelPlugin *plugin)
 
   wavelan->plugin = plugin;
   
-  wavelan->size = xfce_panel_plugin_get_size (plugin);
-  screen_position = xfce_panel_plugin_get_screen_position (plugin);
-  wavelan->orientation = xfce_panel_plugin_get_orientation (plugin);
- 
   wavelan->ebox = gtk_event_box_new();
   gtk_widget_set_has_tooltip(wavelan->ebox, TRUE);
+  gtk_event_box_set_visible_window(GTK_EVENT_BOX(wavelan->ebox), FALSE);
+  gtk_event_box_set_above_child(GTK_EVENT_BOX(wavelan->ebox), TRUE);
   g_signal_connect(wavelan->ebox, "query-tooltip", G_CALLBACK(tooltip_cb), wavelan);
   xfce_panel_plugin_add_action_widget(plugin, wavelan->ebox);
   gtk_container_add(GTK_CONTAINER(plugin), wavelan->ebox);
@@ -324,40 +324,21 @@ wavelan_new(XfcePanelPlugin *plugin)
   g_object_ref( wavelan->tooltip_text );
 
   /* create box for img & progress bar */
-  if (wavelan->orientation == GTK_ORIENTATION_HORIZONTAL)
-    wavelan->box = xfce_hvbox_new(GTK_ORIENTATION_HORIZONTAL, FALSE, 0);
-  else
-    wavelan->box = xfce_hvbox_new(GTK_ORIENTATION_VERTICAL, FALSE, 0);
-  gtk_container_set_border_width(GTK_CONTAINER(wavelan->box), BORDER / 2);
+  wavelan->box = xfce_hvbox_new(wavelan->orientation, FALSE, 0);
 
   /* setup progressbar */
   wavelan->signal = gtk_progress_bar_new();
-  if (wavelan->orientation == GTK_ORIENTATION_HORIZONTAL)
-  {
-    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(wavelan->signal), GTK_PROGRESS_BOTTOM_TO_TOP);
-    gtk_widget_set_size_request(wavelan->signal, 8, -1);
-  } else {
-    gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(wavelan->signal), GTK_PROGRESS_LEFT_TO_RIGHT);
-    gtk_widget_set_size_request(wavelan->signal, -1, 8);
-  }
+  wavelan->image = GTK_WIDGET(xfce_panel_image_new_from_source("network-wireless"));
 
-  wavelan->image = gtk_image_new();
-#ifdef HAS_PANEL_49
-  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size/xfce_panel_plugin_get_nrows(wavelan->plugin)-6, 0, NULL));
-#else
-  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size-6, 0, NULL));
-#endif
+  gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->image), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->signal), FALSE, FALSE, 0);
 
-  gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->image), FALSE, FALSE, 2);
-  gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->signal), FALSE, FALSE, 2);
 
+  wavelan_set_size(plugin, xfce_panel_plugin_get_size (plugin), wavelan);
+  wavelan_set_orientation(plugin, xfce_panel_plugin_get_orientation (plugin),  wavelan);
   gtk_widget_show_all(wavelan->box);
   gtk_container_add(GTK_CONTAINER(wavelan->ebox), GTK_WIDGET(wavelan->box));
   gtk_widget_show_all(wavelan->ebox);
-  if (wavelan->orientation == GTK_ORIENTATION_HORIZONTAL) 
-    gtk_widget_set_size_request(wavelan->ebox, -1, wavelan->size);
-  else
-    gtk_widget_set_size_request(wavelan->ebox, wavelan->size, -1);
   
   wavelan_read_config(plugin, wavelan);
 
@@ -367,7 +348,7 @@ wavelan_new(XfcePanelPlugin *plugin)
 }
 
 static void
-wavelan_free(t_wavelan *wavelan)
+wavelan_free(XfcePanelPlugin* plugin, t_wavelan *wavelan)
 {
   TRACE ("Entered wavelan_free");
   
@@ -420,8 +401,9 @@ wavelan_write_config(XfcePanelPlugin *plugin, t_wavelan *wavelan)
 }
 
 static void
-wavelan_set_orientation(t_wavelan *wavelan, GtkOrientation orientation)
+wavelan_set_orientation(XfcePanelPlugin* plugin, GtkOrientation orientation, t_wavelan *wavelan)
 {
+  DBG("wavelan_set_orientation(%d)", orientation);
   wavelan->orientation = orientation;
   xfce_hvbox_set_orientation(XFCE_HVBOX(wavelan->box), orientation);
   if (orientation == GTK_ORIENTATION_HORIZONTAL) {
@@ -437,14 +419,19 @@ wavelan_set_orientation(t_wavelan *wavelan, GtkOrientation orientation)
 }
 
 static void
-wavelan_set_size(t_wavelan *wavelan, int size)
+wavelan_set_size(XfcePanelPlugin* plugin, int size, t_wavelan *wavelan)
 {
-  wavelan->size = size;
+  int border_width, image_size;
+  DBG("wavelan_set_size(%d)", size);
 #ifdef HAS_PANEL_49
-  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size/xfce_panel_plugin_get_nrows(wavelan->plugin)-6, 0, NULL));
-#else
-  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size-6, 0, NULL));
+  size /= xfce_panel_plugin_get_nrows(plugin);
+  xfce_panel_plugin_set_small (plugin, TRUE);
 #endif
+  border_width = size > 26 ? 2 : 1;
+  wavelan->size = size;
+  image_size = wavelan->size - (2 * border_width);
+  xfce_panel_image_set_size(XFCE_PANEL_IMAGE(wavelan->image), image_size);
+  gtk_container_set_border_width(GTK_CONTAINER(wavelan->box), border_width);
   if (wavelan->orientation == GTK_ORIENTATION_HORIZONTAL)
    gtk_widget_set_size_request(wavelan->ebox, -1, wavelan->size);
   else
@@ -622,41 +609,6 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
   
 }
 
-static void
-wavelan_orientation_changed (XfcePanelPlugin *plugin,
-                             GtkOrientation orientation,
-                             t_wavelan *wavelan)
-{
-    wavelan_set_orientation(wavelan, orientation);
-}
-  
-
-static void
-wavelan_size_changed(XfcePanelPlugin *plugin,
-                     int size,
-                     t_wavelan *wavelan)
-{
-    wavelan_set_size(wavelan, size);
-}
-
-static void 
-wavelan_free_data (XfcePanelPlugin *plugin, t_wavelan *wavelan)
-{
-  wavelan_free(wavelan);
-}
-
-void
-wavelan_save (XfcePanelPlugin *plugin, t_wavelan *wavelan)
-{
-  wavelan_write_config(plugin, wavelan);
-}
-
-static void
-wavelan_configure (XfcePanelPlugin *plugin, t_wavelan *wavelan)
-{
-    wavelan_create_options(plugin, wavelan);
-}
-
 static void
 wavelan_show_about (XfcePanelPlugin *plugin, t_wavelan *wavelan)
 {
@@ -687,24 +639,21 @@ wavelan_construct (XfcePanelPlugin *plugin)
 
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
-/*  g_signal_connect (plugin, "screen-position-changed",
-                    G_CALLBACK (wavelan_screen_position_changed), wavelan);
-*/
   g_signal_connect (plugin, "orientation-changed",
-                    G_CALLBACK (wavelan_orientation_changed), wavelan);
+                    G_CALLBACK (wavelan_set_orientation), wavelan);
 
   g_signal_connect (plugin, "size-changed",
-                    G_CALLBACK (wavelan_size_changed), wavelan);
+                    G_CALLBACK (wavelan_set_size), wavelan);
  
   g_signal_connect (plugin, "free-data",
-                    G_CALLBACK (wavelan_free_data), wavelan);
+                    G_CALLBACK (wavelan_free), wavelan);
 
   g_signal_connect (plugin, "save",
-                    G_CALLBACK (wavelan_save), wavelan);
+                    G_CALLBACK (wavelan_write_config), wavelan);
   
   xfce_panel_plugin_menu_show_configure (plugin);
   g_signal_connect (plugin, "configure-plugin",
-                    G_CALLBACK (wavelan_configure), wavelan);
+                    G_CALLBACK (wavelan_create_options), wavelan);
   
   xfce_panel_plugin_menu_show_about(plugin);
   g_signal_connect (plugin, "about", G_CALLBACK (wavelan_show_about), wavelan);
